@@ -50,8 +50,9 @@ static Gt_ColorTransform *output_transforms;
 #define MERGING		1
 #define BATCHING	2
 #define EXPLODING	3
-#define DELETING	4
-#define INSERTING	5
+#define INFOING		4
+#define DELETING	5
+#define INSERTING	6
 static int mode = BLANK_MODE;
 static int nested_mode = 0;
 
@@ -311,7 +312,9 @@ set_mode(int newmode)
   if (mode == BLANK_MODE)
     mode = newmode;
   else if (mode == newmode)
-    ;
+    /* do nothing */;
+  else if (newmode == INFOING)
+    fatal_error("'--info' suppresses normal output, can't use with an\n  output mode like '--merge' or '--batch'.\n  (Try '-II', which doesn't suppress normal output.)");
   else
     fatal_error("too late to change modes");
 }
@@ -324,7 +327,7 @@ set_frame_change(int kind)
   Gt_Frameset *fset;
   
   if (mode == BLANK_MODE)
-    set_mode(MERGING);
+    set_mode(infoing == 1 ? INFOING : MERGING);
   if (mode < DELETING && frames_done) {
     fatal_error("frame selection and frame changes don't mix");
     return;
@@ -383,18 +386,20 @@ show_frame(int imagenumber, int usename)
   Gif_Image *gfi;
   Gt_Frame *frame;
   
-  if (!input) return;
-  gfi = Gif_GetImage(input, imagenumber);
-  if (!gfi) return;
+  if (!input || !(gfi = Gif_GetImage(input, imagenumber)))
+    return;
   
   switch (mode) {
-    
+
    case MERGING:
    case INSERTING:
    case EXPLODING:
-    if (!frames_done) clear_frameset(frames, first_input_frame);
+   case INFOING:
+    if (!frames_done)
+      clear_frameset(frames, first_input_frame);
     frame = add_frame(frames, -1, input, gfi);
-    if (usename) frame->explode_by_name = 1;
+    if (usename)
+      frame->explode_by_name = 1;
     break;
     
    case BATCHING:
@@ -456,12 +461,12 @@ gifread_error(const char *message, int which_image, void *thunk)
     last_message[0] = 0;
   if (last_which_image != which_image && different_error_count <= 10
       && message) {
-    error("Error while reading `%s' frame #%d:", filename, which_image);
+    error("Error while reading '%s' frame #%d:", filename, which_image);
     last_which_image = which_image;
   }
   
   if (different_error_count == 11 && message) {
-    error("(more errors while reading `%s')", filename);
+    error("(more errors while reading '%s')", filename);
     different_error_count++;
   }
 }
@@ -486,6 +491,9 @@ input_stream(const char *name)
   if (next_output)
     combine_output_options();
   files_given++;
+
+  if (infoing == 1)
+    set_mode(INFOING);
   
   if (name == 0 || strcmp(name, "-") == 0) {
 #if defined(_MSDOS) || defined(_WIN32)
@@ -585,7 +593,7 @@ input_stream(const char *name)
               g.gif --name=X    h.gif   // name on h.gif #0 !!!
       
      Here's the solution. Mark when we CHANGE an option. After processing
-     an input GIF, mark all the options as `unchanged' -- but leave the
+     an input GIF, mark all the options as 'unchanged' -- but leave the
      VALUES as is. Then when we read the next frame, CLEAR the unchanged
      options. So it's like so: (* means changed, . means not.)
      
@@ -614,10 +622,10 @@ input_stream(const char *name)
   if (unoptimizing)
     if (!Gif_Unoptimize(gfs)) {
       static int context = 0;
-      warning("`%s' is too complex to unoptimize", name);
+      warning("'%s' is too complex to unoptimize", name);
       if (!context) {
 	warncontext("(The reason was local color tables or complex transparency.");
-	warncontext("Try running the GIF through `gifsicle --colors=255' first.)");
+	warncontext("Try running the GIF through 'gifsicle --colors=255' first.)");
       }
       context = 1;
     }
@@ -793,7 +801,8 @@ merge_and_write_frames(const char *outfile, int f1, int f2)
   int colormap_change;
   int huge_stream;
   assert(!nested_mode);
-  if (verbosing) verbose_open('[', outfile ? outfile : "#stdout#");
+  if (verbosing)
+    verbose_open('[', outfile ? outfile : "#stdout#");
 
   colormap_change = active_output_data.colormap_size > 0
     || active_output_data.colormap_fixed;
@@ -874,7 +883,7 @@ void
 output_frames(void)
 {
   /* Use the current output name, not the stored output name.
-     This supports `gifsicle a.gif -o xxx'.
+     This supports 'gifsicle a.gif -o xxx'.
      It's not like any other option, but seems right: it fits the natural
      order -- input, then output. */
   int i;
@@ -890,6 +899,7 @@ output_frames(void)
       
      case MERGING:
      case BATCHING:
+     case INFOING:
       merge_and_write_frames(outfile, 0, -1);
       break;
       
@@ -932,7 +942,7 @@ output_frames(void)
   active_next_output = 0;
   clear_frameset(frames, 0);
   
-  /* cropping: clear the `crop->ready' information, which depended on the last
+  /* cropping: clear the 'crop->ready' information, which depended on the last
      input image. */
   if (def_frame.crop)
     def_frame.crop->ready = 0;
@@ -946,7 +956,7 @@ output_frames(void)
 int
 frame_argument(Clp_Parser *clp, const char *arg)
 {
-  /* Returns 0 iff you should try a file named `arg'. */
+  /* Returns 0 iff you should try a file named 'arg'. */
   int val = parse_frame_spec(clp, arg, -1, 0);
   if (val == -97)
     return 0;
@@ -954,7 +964,8 @@ frame_argument(Clp_Parser *clp, const char *arg)
     int i;
     for (i = frame_spec_1; i <= frame_spec_2; i++)
       show_frame(i, frame_spec_name != 0);
-    if (next_output) combine_output_options();
+    if (next_output)
+      combine_output_options();
     return 1;
   } else
     return 1;
@@ -1193,7 +1204,7 @@ main(int argc, char *argv[])
   
   /* Yep, I'm an idiot.
      GIF dimensions are unsigned 16-bit integers. I assume that these
-     numbers will fit in an `int'. This assertion tests that assumption.
+     numbers will fit in an 'int'. This assertion tests that assumption.
      Really I should go through & change everything over, but it doesn't
      seem worth my time. */
   {
@@ -1242,7 +1253,8 @@ main(int argc, char *argv[])
 	def_frame.colormap_info = 0;
       else {
 	def_frame.colormap_info = 1;
-	if (!infoing) infoing = 1;
+	if (!infoing)
+	  infoing = 1;
       }
       break;
       
@@ -1251,7 +1263,8 @@ main(int argc, char *argv[])
 	def_frame.extensions_info = 0;
       else {
 	def_frame.extensions_info = 1;
-	if (!infoing) infoing = 1;
+	if (!infoing)
+	  infoing = 1;
       }
       break;
       
@@ -1532,7 +1545,7 @@ main(int argc, char *argv[])
 	 input_transforms = delete_color_transforms
 	   (input_transforms, &color_change_transformer);
        else if (parsed_color2.haspixel)
-	 error("COLOR2 must be in RGB format in `--change-color COLOR1 COLOR2'");
+	 error("COLOR2 must be in RGB format in '--change-color COLOR1 COLOR2'");
        else
 	 input_transforms = append_color_change
 	   (input_transforms, parsed_color, parsed_color2);
@@ -1557,7 +1570,7 @@ main(int argc, char *argv[])
 	def_output_data.colormap_size = clp->val.i;
 	if (def_output_data.colormap_size < 2
 	    || def_output_data.colormap_size > 256) {
-	  Clp_OptionError(clp, "argument to `%O' must be between 2 and 256");
+	  Clp_OptionError(clp, "argument to '%O' must be between 2 and 256");
 	  def_output_data.colormap_size = 0;
 	}
       }
@@ -1587,7 +1600,7 @@ main(int argc, char *argv[])
       if (clp->negated)
 	def_output_data.scaling = 0;
       else if (dimensions_x <= 0 && dimensions_y <= 0) {
-	error("one of W and H must be positive in `--resize WxH'");
+	error("one of W and H must be positive in '--resize WxH'");
 	def_output_data.scaling = 0;
       } else {
 	def_output_data.scaling = 1; /* use resize dimensions */
@@ -1601,7 +1614,7 @@ main(int argc, char *argv[])
       if (clp->negated)
 	def_output_data.scaling = 0;
       else if (clp->val.u == 0) {
-	error("`--resize-width' argument must be positive");
+	error("'--resize-width' argument must be positive");
 	def_output_data.scaling = 0;
       } else {
 	def_output_data.scaling = 1; /* use resize dimensions */
@@ -1615,7 +1628,7 @@ main(int argc, char *argv[])
       if (clp->negated)
 	def_output_data.scaling = 0;
       else if (clp->val.u == 0) {
-	error("`--resize-height' argument must be positive");
+	error("'--resize-height' argument must be positive");
 	def_output_data.scaling = 0;
       } else {
 	def_output_data.scaling = 1; /* use resize dimensions */
@@ -1629,7 +1642,7 @@ main(int argc, char *argv[])
       if (clp->negated)
 	def_output_data.scaling = 0;
       else if (parsed_scale_factor_x <= 0 || parsed_scale_factor_y <= 0) {
-	error("`--scale' X and Y factors must be positive");
+	error("'--scale' X and Y factors must be positive");
 	def_output_data.scaling = 0;
       } else {
 	def_output_data.scaling = 2; /* use scale factor */
@@ -1666,7 +1679,7 @@ main(int argc, char *argv[])
 #else
       printf("LCDF Gifsicle %s\n", VERSION);
 #endif
-      printf("Copyright (C) 1997-2003 Eddie Kohler\n\
+      printf("Copyright (C) 1997-2005 Eddie Kohler\n\
 This is free software; see the source for copying conditions.\n\
 There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
@@ -1719,7 +1732,7 @@ particular purpose.\n");
   
   frame_change_done();
   input_done();
-  if (mode == MERGING)
+  if (mode == MERGING || mode == INFOING)
     output_frames();
   
   verbose_endline();
